uaboRA2FrameGroup = uabFrameGroup:NewModule("oRA2")

uaboRA2FrameGroup.controls = {}
uaboRA2FrameGroup.defaultDB = {
    framegroups = {
        ["Main Tank"] = {
            expression = "^oRAMainTankUnitButton%d+$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Main Tank Target"] = {
            expression = "^oRAMainTankUnitButton%d+Target$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Main Tank Target of Target"] = {
            expression = "^oRAMainTankUnitButton%d+TargetTarget$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Player Target"] = {
            expression = "^oRAPlayerTargetUnitButton%d+$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Player Target Target"] = {
            expression = "^oRAPlayerTargetUnitButton%d+Target$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Player Target ToT"] = {
            expression = "^oRAPlayerTargetUnitButton%d+TargetTarget$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
    },
}

function uaboRA2FrameGroup:OnInitialize()
    self.super.OnInitialize(self)
end

function uaboRA2FrameGroup:OnEnable()
end

function uaboRA2FrameGroup:OnDisable()
end

function uaboRA2FrameGroup:NewActivator(activator)
    --[[
    We create 6 controls for the partyraid unit group, since
    the oRA2 frames will go into that group, and there are 6
    possible frames to be allocated for each unit (each person
    could be a player target and a MT.
    --]]
	self.controls[activator] = {}
    self.controls[activator].partyraid = {}
	for idx = 1, uab.constants.groupInfo.partyraid.unitcount do
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
    end
end

function uaboRA2FrameGroup:HaveFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)
	
	if not options then return end

	if self.controls[activator] and self.controls[activator][options.unitgroup] then
		return # self.controls[activator][options.unitgroup] > 0
	end
end

function uaboRA2FrameGroup:NextFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)

	if not options then return end
	
    if self.controls[activator] and self.controls[activator][options.unitgroup]
        and # self.controls[activator][options.unitgroup] > 0 then
		control = table.remove(self.controls[activator][options.unitgroup])
	end

	return control
end

function uaboRA2FrameGroup:OptionsForFrame(frame)
    for name, defn in pairs(self.db.profile.framegroups) do
        if self:MatchFrame(frame, defn) then
            return name, defn
        end
    end
end

function uaboRA2FrameGroup:CreateFrameGroupOptions()
    local args = {}

    args = {
        type = 'group',
        name = "oRA2",
        desc = "Use, anchor, scale, and match expression for the oRA2 frames",
        args = {
            enabled = {
                type = 'toggle',
                name = "Enabled",
                desc = "When checked, enable the use of UAB action sets for oRA2 frames",
                order = 1,
                get = function()
                    return not self.db.profile.disabled
                end,
                set = function(v)
                    self.db.profile.disabled = not v
                    self.core.core.main:FrameGroupsChanged()
                end,
            },
            
            spacing3 = {
                name = " ",
                type = 'header',
                order = 5,
            },
        
        },
    }
    
    args.args["Main Tank"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Main Tank"], "Main Tank", "oRA2 Main Tank")
    args.args["Main Tank"].disabled = function() return self.db.profile.disabled end
    args.args["Main Tank"].order = 10
    
    args.args["Main Tank Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Main Tank Target"], "Main Tank Target", "oRA2 Main Tank Target")
    args.args["Main Tank Target"].disabled = function() return self.db.profile.disabled end
    args.args["Main Tank Target"].order = 20
    
    args.args["Main Tank Target of Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Main Tank Target of Target"], "Main Tank Target of Target", "oRA2 Main Tank Target of Target")
    args.args["Main Tank Target of Target"].disabled = function() return self.db.profile.disabled end
    args.args["Main Tank Target of Target"].order = 30
    
    args.args["Player Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Target"], "Player Target", "oRA2 Player Target")
    args.args["Player Target"].disabled = function() return self.db.profile.disabled end
    args.args["Player Target"].order = 40
    
    args.args["Player Target Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Target Target"], "Player Target Target", "oRA2 Player Target Target")
    args.args["Player Target Target"].disabled = function() return self.db.profile.disabled end
    args.args["Player Target Target"].order = 50
    
    args.args["Player Target ToT"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Target ToT"], "Player Target ToT", "oRA2 Player Target ToT")
    args.args["Player Target ToT"].disabled = function() return self.db.profile.disabled end
    args.args["Player Target ToT"].order = 60
    
    return args
end

function uaboRA2FrameGroup:SetupLayouts()
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Main Tank"].layout, self, "Main Tank")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Main Tank Target"].layout, self, "Main Tank Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Main Tank Target of Target"].layout, self, "Main Tank Target of Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Player Target"].layout, self, "Player Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Player Target Target"].layout, self, "Player Target Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Player Target ToT"].layout, self, "Player Target ToT")
end

function uaboRA2FrameGroup:SetLayoutConfigureOptions(name, args)
    uab.print("agufFrameGroup:SetLayoutConfigureOptions: "..self.name.." : "..name)
    
    self.core.core.options.args.lookandfeel.args.framegroups.args[self.name].args[name].args.layout.args.configure.args = args
end

